@@ -258,7 +258,9 @@ calc_hf <- function(dat, constants) {
   hfhf_dm <- constants[4]
   luhf_dm <- constants[5]
   luhf_zrc <- constants[6]
-  if (!('hfhf' %in% names(dat))) return(dat)
+  if ('ehf_i' %in% names(dat)) {
+    dat <- dat[, !(names(dat) %in% c('hfhf', 'hfhfse', 'luhf'))]
+  }
   if (is.vector(dat) || ncol(dat) < 3) {
     stop('Data must contain at least three columns')
   }
